@@ -1,4 +1,6 @@
 import typing
+from collections import defaultdict
+from typing import List
 from typing import Type
 from typing import Iterable
 from typing import Optional
@@ -7,6 +9,7 @@ from typer import Typer
 from rich.console import Console
 from botocore.exceptions import ClientError
 
+from ei.__about__ import VERSION
 from ei.core import defaults
 from ei.core.fields import Field
 from ei.core.service import BaseAwsService
@@ -22,6 +25,22 @@ if typing.TYPE_CHECKING:
     from typing import Callable  # noqa: F401
 
 
+SUBJECTS = ['Region', 'Account']
+
+
+def create_application(apps: List['Typeable']) -> Typer:
+    cli = CliGroup(
+        name='ei',
+        description=(
+            'A[bold green](ei)[/bold green]'
+            f' - AWS CLI for humans. ({VERSION})\n\n'
+        ),
+        apps=apps
+    )
+
+    return cli.typer()
+
+
 def _get_typer(name: str, help: str) -> Typer:
     app = Typer(
         name=name,
@@ -118,16 +137,22 @@ class BaseCliApp(Typeable):
             self,
             long: bool = False,
             stat: bool = True,
+            table: bool = True,
             region: str = '',
             account_id: str = '',
             all_regions: bool = False,
-            all_accounts: bool = False) -> None:
+            all_accounts: bool = False) -> int:
         """List resources
         """
 
-        _preflight()
-        self._validate_region(region)
-        self._validate_acocunt_id(account_id)
+        try:
+            _preflight()
+            self._validate_region(region)
+            self._validate_acocunt_id(account_id)
+
+        except PreflightError as e:
+            self._console.print(e)
+            return 1
 
         if long:
             fields = self._list_detail_fields
@@ -149,32 +174,53 @@ class BaseCliApp(Typeable):
 
         display_fields = additional_fields + [*fields]
         try:
-            results = bulk_action(self._service.list, regions, account_ids)
+            results = [*bulk_action(self._service.list, regions, account_ids)]
             serialized_results = _serialize_data_as_list(
                 display_fields, results)
 
-            table = list_table([
-                field._name for field in display_fields
-            ], serialized_results)
-            self._console.print(table)
+            if table:
+                display_table = list_table([
+                    field._name for field in display_fields
+                ], serialized_results)
+                self._console.print(display_table)
 
             if stat:
+                stats_dict: dict = {}
+                for subject in SUBJECTS:
+                    stats_dict[subject] = defaultdict(int)
+
+                    for item in results:
+                        stats_dict[subject][item[subject]] += 1
+
                 self._console.print(
                     f'{len(serialized_results)} "{self.name}" items.')
 
+                for subject in SUBJECTS:
+                    self._console.print(f'\n* per {subject}')
+                    for key, count in stats_dict[subject].items():
+                        self._console.print(
+                            f'  - "{key}": {count} items.')
+
         except ClientError as e:
             print(e)
+            return 1
+
+        return 0
 
     def show(
             self,
             id: str,
             region: str = '',
-            account_id: str = '') -> None:
+            account_id: str = '') -> int:
         """Show resource
         """
+        try:
+            _preflight()
+            self._validate_region(region)
 
-        _preflight()
-        self._validate_region(region)
+        except PreflightError as e:
+            self._console.print(e)
+            return 1
 
         try:
             result = self._service.show(id, region, account_id)
@@ -186,12 +232,15 @@ class BaseCliApp(Typeable):
 
         except ClientError as e:
             print(e)
+            return 1
+
+        return 0
 
     def typer(self) -> Typer:
         commands = [
             self.list,
             self.show
-        ]  # type: list[Callable]
+        ]  # type: List[Callable]
         available_commands = ', '.join([
             f'[bright_blue]{cmd.__name__}[/bright_blue]'
             for cmd in commands
@@ -213,13 +262,13 @@ class BaseCliApp(Typeable):
 
 
 class CliGroup(Typeable):
-    _apps: list[Typeable]
+    _apps: List[Typeable]
 
     def __init__(
             self,
             name: str,
             description: str,
-            apps: Optional[list[Typeable]] = None
+            apps: Optional[List[Typeable]] = None
             ) -> None:
 
         self.name = name
